@@ -1,13 +1,9 @@
-
 import re
-
 import pandas as pd
-
 from dhlab.api.dhlab_api import get_document_frequencies, concordance, urn_collocation
-from dhlab.text.corpus import urnlist
-
-from typing import  Union
-
+# from dhlab.text.corpus import urnlist
+from dhlab.text.dhlab_object import DhlabObj
+from dhlab.text.utils import urnlist
 
 # convert cell to a link
 def make_link(row):
@@ -17,32 +13,26 @@ def make_link(row):
 
 
 # find hits a cell
-def find_hits(x): return ' '.join(re.findall("<b>(.+?)</b", x))
+def find_hits(x):
+    return ' '.join(re.findall("<b>(.+?)</b", x))
 
-
-class Concordance():
+class Concordance(DhlabObj):
     """Wrapper for concordance function with added functionality"""
 
     def __init__(self, corpus=None, query=None, window=20, limit=500):
 
-        self.concordance = concordance(urns=urnlist(corpus), words=query, window=window, limit=limit)
+        self.concordance = concordance(urns=urnlist(corpus),
+                                       words=query,
+                                       window=window,
+                                       limit=limit)
         self.concordance['link'] = self.concordance.urn.apply(make_link)
         self.concordance = self.concordance[['link', 'urn', 'conc']]
         self.concordance.columns = ['link', 'urn', 'concordance']
         self.corpus = corpus
         self.size = len(self.concordance)
 
-    def __repr__(self) -> str:
-        """
-        Return the string representation of the concordance datafrane
-        """
-        return self.corpus.__repr__()
-    
-    def _repr_html_(self) -> Union[str, None]:
-        """
-        Return the HTML representation of the concordance datafrane
-        """
-        return self.corpus._repr_html_()   
+
+        super().__init__(self.concordance)
 
     def show(self, n=10, style=True):
         if style:
@@ -53,7 +43,8 @@ class Concordance():
         return result
 
 
-class Collocations():
+
+class Collocations(DhlabObj):
     """Collocations """
 
     def __init__(
@@ -88,9 +79,7 @@ class Collocations():
         """
         if isinstance(words, str):
             words = [words]
-        
-        
-                
+
         coll = pd.concat(
             [
                 urn_collocation(
@@ -103,13 +92,12 @@ class Collocations():
                 for w in words
             ]
         )[['counts']]
-        
+
         if alpha:
             coll = coll.loc[[x for x in coll.index if x.isalpha()]]
             if reference is not None:
                 reference = reference.loc[[x for x in reference.index if x.isalpha()]]
-            
-            
+
         if ignore_caps:
             coll.index = [x.lower() for x in coll.index]
             if reference is not None:
@@ -119,27 +107,16 @@ class Collocations():
         self.reference = reference
         self.before = before
         self.after = after
-       
 
         if reference is not None:
             teller = self.coll.counts / self.coll.counts.sum()
             divisor = self.reference.iloc[:, 0] / self.reference.iloc[:, 0].sum()
             self.coll['relevance'] = teller / divisor
-            
-    def __repr__(self) -> str:
-        """
-        Return the string representation of the collocation datafrane
-        """
-        return self.coll.__repr__()
-    
-    def _repr_html_(self) -> Union[str, None]:
-        """
-        Return the HTML representation of the collocation datafrane
-        """
-        return self.coll._repr_html_()       
+
+        super().__init__(self.coll)
 
     def show(self, sortby='counts', n=20):
-        return self.coll.sort_values(by=sortby, ascending=False)
+        return self.coll.sort_values(by=sortby, ascending=False).head(n)
 
     def keywordlist(self, top=200, counts=5, relevance=10):
         mask = self.coll[self.coll.counts > counts]
@@ -147,29 +124,35 @@ class Collocations():
         return list(mask.sort_values(
             by='counts', ascending=False).head(200).index)
 
+    @classmethod
+    def from_df(cls, df):
+        obj = Counts()
+        obj.counts = df
+        obj.frame = df
+        return obj
 
-class Counts():
+class Counts(DhlabObj):
     """Provide counts for a corpus - shouldn't be too large"""
 
     def __init__(self, corpus=None, words=None):
         if corpus is None and words is None:
-            self.counts = None
+            self.counts = pd.DataFrame()
         elif not corpus is None:
             # count - if words is none result will be as if counting all words
             # in the corpus
             self.counts = get_document_frequencies(
                 urns=urnlist(corpus), cutoff=0, words=words)
 
+        super().__init__(self.counts)
 
-    def __repr__(self) -> str:
-        """
-        Return the string representation of the counts datafrane
-        """
-        return self.counts.__repr__()
-    
-    def _repr_html_(self) -> Union[str, None]:
-        """
-        Return the HTML representation of the counts datafrane
-        """
-        return self.counts._repr_html_()  
-        
\ No newline at end of file
+    def sum(self):
+        c = Counts()
+        c.counts = self.counts.sum(axis=1)
+        return c
+
+    @classmethod
+    def from_df(cls, df):
+        obj = Counts()
+        obj.counts = df
+        obj.frame = df
+        return obj
